kedro.framework.cli.hooks — Kedro 0.17.6 documentation

# kedro.framework.cli.hooks

Description

`kedro.framework.cli.hooks` provides primitives to use hooks to extend KedroCLI’s behaviour

Modules

`kedro.framework.cli.hooks.manager` | This module defines a dedicated hook manager for hooks that extends Kedro CLI behaviour.
`kedro.framework.cli.hooks.markers` | This module provides markers to declare Kedro CLI’s hook specs and implementations.
`kedro.framework.cli.hooks.specs` | A module containing specifications for all callable hooks in the Kedro CLI’s execution timeline.